==> sslexplorer-0.2.13-src.tar.gz: sslexplorer-0.2.13/sslexplorer/src/com/sslexplorer/core/stringreplacement/PolicyAttributesReplacer.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.core.stringreplacement;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.sslexplorer.boot.PropertyClass;
import com.sslexplorer.boot.PropertyClassManager;
import com.sslexplorer.boot.Replacer;
import com.sslexplorer.policyframework.Policy;
import com.sslexplorer.properties.Property;
import com.sslexplorer.properties.attributes.AttributeDefinition;
import com.sslexplorer.properties.impl.policyattributes.PolicyAttributeKey;
import com.sslexplorer.properties.impl.policyattributes.PolicyAttributes;

public class PolicyAttributesReplacer implements Replacer {
    
    final static Log log = LogFactory.getLog(PolicyAttributesReplacer.class);
    
    private Policy policy;
    
    public PolicyAttributesReplacer(Policy policy) {
        this.policy = policy;            
    }

    public String getReplacement(Pattern pattern, Matcher matcher, String replacementPattern) {
        String match = matcher.group();
        String key = match.substring(2, match.length() - 1);
        try {
            int idx = key.indexOf(":");
            if (idx == -1) {
                throw new Exception("String replacement pattern is in incorrect format for " + key
                    + ". Must be <TYPE>:<key>");
            }
            String type = key.substring(0, idx);
            key = key.substring(idx + 1);
            if (VariableReplacement.log.isDebugEnabled())
                VariableReplacement.log.debug("Found replacement variable " + type + ":" + key);
            if (type.equalsIgnoreCase(PolicyAttributes.NAME)) {
                PropertyClass propertyClass = PropertyClassManager.getInstance().getPropertyClass(type);
                AttributeDefinition def = (AttributeDefinition) propertyClass.getDefinition(key);
                if (def == null) {
                    VariableReplacement.log.warn("Invalid policy attribute '" + key + "'");
                    return null;
                } else {
                    return Property.getProperty(new PolicyAttributeKey(policy.getResourceId(), key));
                }
            }
        } catch (Exception e) {
           log.error("A replacement failed for " + key + ".", e);
        }
        return null;
    }
    
}

==> sslexplorer-0.2.15_01-src.tar.gz: sslexplorer-0.2.15_01/sslexplorer/src/com/sslexplorer/core/stringreplacement/PolicyAttributesReplacer.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.core.stringreplacement;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import com.sslexplorer.boot.PropertyClass;
import com.sslexplorer.boot.PropertyClassManager;
import com.sslexplorer.policyframework.Policy;
import com.sslexplorer.properties.Property;
import com.sslexplorer.properties.attributes.AttributeDefinition;
import com.sslexplorer.properties.impl.policyattributes.PolicyAttributeKey;
import com.sslexplorer.properties.impl.policyattributes.PolicyAttributes;

public class PolicyAttributesReplacer extends AbstractReplacementVariableReplacer {
    
    private Policy policy;
    
    public PolicyAttributesReplacer(Policy policy) {
    	super();
        this.policy = policy;            
    }

	@Override
	public String processReplacementVariable(Pattern pattern, Matcher matcher, String replacementPattern, String type, String key) throws Exception {
		if (type.equalsIgnoreCase(PolicyAttributes.NAME)) {
            PropertyClass propertyClass = PropertyClassManager.getInstance().getPropertyClass(type);
            AttributeDefinition def = (AttributeDefinition) propertyClass.getDefinition(key);
            if (def == null) {
                VariableReplacement.log.warn("Invalid policy attribute '" + key + "'");
                return null;
            } else {
                return Property.getProperty(new PolicyAttributeKey(policy.getResourceId(), key));
            }
        }
		return null;
	}
    
}
